From 2f8fef92b3fce1cfec7244e1bdca7e63f52b8a6c Mon Sep 17 00:00:00 2001
From: dan <igaryhe@gmail.com>
Date: Sun, 7 Nov 2021 21:57:24 +0800
Subject: [PATCH] gnu: Add fcitx5-rime.

* gnu/packages/fcitx5.scm (fcitx5-rime): New variable.

---
 gnu/packages/fcitx5.scm | 47 +++++++++++++++++++++++++++++++++++++++--
 1 file changed, 45 insertions(+), 2 deletions(-)

diff --git a/gnu/packages/fcitx5.scm b/gnu/packages/fcitx5.scm
index 0c4980aba2..27c28d56e1 100644
--- a/gnu/packages/fcitx5.scm
+++ b/gnu/packages/fcitx5.scm
@@ -1,6 +1,7 @@
 ;;; GNU Guix --- Functional package management for GNU
 ;;; Copyright © 2020 Zhu Zihao <all_but_last@163.com>
 ;;; Copyright © 2021 Tobias Geerinckx-Rice <me@tobias.gr>
+;;; Copyright © 2021 dan <igaryhe@gmail.com>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -47,7 +48,8 @@ (define-module (gnu packages fcitx5)
   #:use-module (gnu packages web)
   #:use-module (gnu packages xdisorg)
   #:use-module (gnu packages xml)
-  #:use-module (gnu packages xorg))
+  #:use-module (gnu packages xorg)
+  #:use-module (gnu packages ibus))
 
 (define-public xcb-imdkit
   (package
@@ -139,7 +141,11 @@ (define-public fcitx5
     (native-search-paths
      (list (search-path-specification
             (variable "FCITX_ADDON_DIRS")
-            (files '("lib/fcitx5")))))
+            (files '("lib/fcitx5")))
+           ; export XDG_DATA_DIRS so that fcitx5 could search other addons
+           (search-path-specification
+            (variable "XDG_DATA_DIRS")
+            (files '("share")))))
     (home-page "https://github.com/fcitx/fcitx5")
     (synopsis "Input method framework")
     (description "Fcitx 5 is a generic input method framework.")
@@ -453,3 +459,40 @@ (define (install-theme-variant variant target)
 @item DeepPurple
 @end itemize\n")
     (license license:asl2.0)))
+
+(define-public fcitx5-rime
+  (package
+    (name "fcitx5-rime")
+    (version "5.0.8")
+    (source
+     (origin
+       (method url-fetch)
+       (uri (string-append
+             "https://download.fcitx-im.org/fcitx5"
+             "/fcitx5-rime/fcitx5-rime-" version ".tar.xz"))
+       (sha256
+        (base32 "0rl8ng11jprzi3lvx3jdim5b5y8k31l14jgjricxzw5i3fvfqzp3"))))
+    (build-system cmake-build-system)
+    (arguments
+     '(#:tests? #f                      ; no tests
+       #:configure-flags
+       (list (string-append "-DRIME_DATA_DIR="
+			    (assoc-ref %build-inputs "rime-data")
+			    "/share/rime-data"))))
+    (inputs
+     `(("fcitx5", fcitx5)
+       ("librime", librime)
+       ("rime-data", rime-data)))
+    (native-inputs
+     `(("gettext", gettext-minimal)
+       ("extra-cmake-modules", extra-cmake-modules)
+       ("pkg-config", pkg-config)))
+    (home-page "https://github.com/fcitx/fcitx5-rime")
+    (synopsis "Rime Input Method Engine for Fcitx 5")
+    (description "@dfn{fcitx5-rime} provides the Rime input method engine for
+fcitx5.  Rime is a lightweight, extensible input method engine supporting
+various input schemas including glyph-based input methods, romanization-based
+input methods as well as those for Chinese dialects.  It has the ability to
+compose phrases and sentences intelligently and provide very accurate
+traditional Chinese output.")
+    (license license:lgpl2.1+)))
-- 
2.33.1

